@@ -1,6 +1,13 @@
-import logging
+# -------------------------------------------------------------
+# code developed by Michael Hartmann during his Ph.D.
+# Reachability Analysis
+#
+# (C) 2020 Michael Hartmann, Graz, Austria
+# Released under GNU GENERAL PUBLIC LICENSE
+# email michael.hartmann@v2c2.at
+# -------------------------------------------------------------
 import reachab.src.reachability as rb
-
+import matplotlib.pyplot as plt
 def test_me():
     obj_reachability = rb.reachability()
     obj_reachability.test_function()
@@ -23,10 +30,14 @@ def reach(Omega_0, U, params):
     for act_zono in R:
         zonoset = obj_reach.get_points_of_zonotype(act_zono)
         if (params['visualization'] == 'y'):
-            obj_reach.obj_visual.filled_polygon(zonoset, 'green', .2)
+            obj_reach.obj_visual.filled_polygon(zonoset, 'orange', .2)
         erg.append(zonoset)
-    if (params['visualization'] == 'y'):
-        obj_reach.obj_visual.show()
     return erg
 
 
+def show_all():
+    plt.axis('equal')
+    plt.grid("on")
+    plt.show()
+
+
